import type { EntryListHandle, Jwk, Key, KeyEntryListHandle, LocalKeyHandle, ScanHandle, SessionHandle, StoreHandle } from '../crypto';
import type { KeyAlgs, LogLevel, SigAlgs } from '../enums';
import type { AeadParams, EncryptedBuffer } from '../types';
export declare type ErrorCode = number;
export declare type NativeLogCallback = (context: unknown, level: number, target: string, message: string, modulePath: string, file: string, line: number) => void;
export declare type SetCustomLoggerOptions = {
    logLevel: LogLevel;
    flush?: boolean;
    enabled?: boolean;
    logger: NativeLogCallback;
};
export declare type SetMaxLogLevelOptions = {
    logLevel: number;
};
export declare type EntryListCountOptions = {
    entryListHandle: EntryListHandle;
};
export declare type EntryListFreeOptions = {
    entryListHandle: EntryListHandle;
};
export declare type EntryListGetCategoryOptions = {
    entryListHandle: EntryListHandle;
    index: number;
};
export declare type EntryListGetNameOptions = {
    entryListHandle: EntryListHandle;
    index: number;
};
export declare type EntryListGetTagsOptions = {
    entryListHandle: EntryListHandle;
    index: number;
};
export declare type EntryListGetValueOptions = {
    entryListHandle: EntryListHandle;
    index: number;
};
export declare type KeyAeadDecryptOptions = {
    localKeyHandle: LocalKeyHandle;
    ciphertext: Uint8Array;
    nonce: Uint8Array;
    tag?: Uint8Array;
    aad?: Uint8Array;
};
export declare type KeyAeadEncryptOptions = {
    localKeyHandle: LocalKeyHandle;
    message: Uint8Array;
    nonce?: Uint8Array;
    aad?: Uint8Array;
};
export declare type KeyAeadGetPaddingOptions = {
    localKeyHandle: LocalKeyHandle;
    msgLen: number;
};
export declare type KeyAeadGetParamsOptions = {
    localKeyHandle: LocalKeyHandle;
};
export declare type KeyAeadRandomNonceOptions = {
    localKeyHandle: LocalKeyHandle;
};
export declare type KeyConvertOptions = {
    localKeyHandle: LocalKeyHandle;
    algorithm: KeyAlgs;
};
export declare type KeyCryptoBoxOptions = {
    recipientKey: Key;
    senderKey: Key;
    message: Uint8Array;
    nonce: Uint8Array;
};
export declare type KeyCryptoBoxOpenOptions = {
    recipientKey: Key;
    senderKey: Key;
    message: Uint8Array;
    nonce: Uint8Array;
};
export declare type KeyCryptoBoxSealOptions = {
    localKeyHandle: LocalKeyHandle;
    message: Uint8Array;
};
export declare type KeyCryptoBoxSealOpenOptions = {
    localKeyHandle: LocalKeyHandle;
    ciphertext: Uint8Array;
};
export declare type KeyDeriveEcdh1puOptions = {
    algorithm: KeyAlgs;
    ephemeralKey: Key;
    senderKey: Key;
    recipientKey: Key;
    algId: Uint8Array;
    apu: Uint8Array;
    apv: Uint8Array;
    ccTag?: Uint8Array;
    receive: boolean;
};
export declare type KeyDeriveEcdhEsOptions = {
    algorithm: KeyAlgs;
    ephemeralKey: Key;
    recipientKey: Key;
    algId: Uint8Array;
    apu: Uint8Array;
    apv: Uint8Array;
    receive: boolean;
};
export declare type KeyEntryListCountOptions = {
    keyEntryListHandle: KeyEntryListHandle;
};
export declare type KeyEntryListFreeOptions = {
    keyEntryListHandle: KeyEntryListHandle;
};
export declare type KeyEntryListGetAlgorithmOptions = {
    keyEntryListHandle: KeyEntryListHandle;
    index: number;
};
export declare type KeyEntryListGetMetadataOptions = {
    keyEntryListHandle: KeyEntryListHandle;
    index: number;
};
export declare type KeyEntryListGetNameOptions = {
    keyEntryListHandle: KeyEntryListHandle;
    index: number;
};
export declare type KeyEntryListGetTagsOptions = {
    keyEntryListHandle: KeyEntryListHandle;
    index: number;
};
export declare type KeyEntryListLoadLocalOptions = {
    keyEntryListHandle: KeyEntryListHandle;
    index: number;
};
export declare type KeyFreeOptions = {
    localKeyHandle: LocalKeyHandle;
};
export declare type KeyFromJwkOptions = {
    jwk: Jwk;
};
export declare type KeyFromKeyExchangeOptions = {
    algorithm: KeyAlgs;
    skHandle: LocalKeyHandle;
    pkHandle: LocalKeyHandle;
};
export declare type KeyFromPublicBytesOptions = {
    algorithm: KeyAlgs;
    publicKey: Uint8Array;
};
export declare type KeyFromSecretBytesOptions = {
    algorithm: KeyAlgs;
    secretKey: Uint8Array;
};
export declare type KeyFromSeedOptions = {
    algorithm: KeyAlgs;
    seed: Uint8Array;
    method: string;
};
export declare type KeyGenerateOptions = {
    algorithm: KeyAlgs;
    ephemeral: boolean;
};
export declare type KeyGetAlgorithmOptions = {
    localKeyHandle: LocalKeyHandle;
};
export declare type KeyGetEphemeralOptions = {
    localKeyHandle: LocalKeyHandle;
};
export declare type KeyGetJwkPublicOptions = {
    localKeyHandle: LocalKeyHandle;
    algorithm: string;
};
export declare type KeyGetJwkSecretOptions = {
    localKeyHandle: LocalKeyHandle;
};
export declare type KeyGetJwkThumbprintOptions = {
    localKeyHandle: LocalKeyHandle;
    algorithm: string;
};
export declare type KeyGetPublicBytesOptions = {
    localKeyHandle: LocalKeyHandle;
};
export declare type KeyGetSecretBytesOptions = {
    localKeyHandle: LocalKeyHandle;
};
export declare type KeySignMessageOptions = {
    localKeyHandle: LocalKeyHandle;
    message: Uint8Array;
    sigType?: SigAlgs;
};
export declare type KeyUnwrapKeyOptions = {
    localKeyHandle: LocalKeyHandle;
    algorithm: KeyAlgs;
    ciphertext: Uint8Array;
    nonce?: Uint8Array;
    tag?: Uint8Array;
};
export declare type KeyVerifySignatureOptions = {
    localKeyHandle: LocalKeyHandle;
    message: Uint8Array;
    signature: Uint8Array;
    sigType?: SigAlgs;
};
export declare type KeyWrapKeyOptions = {
    localKeyHandle: LocalKeyHandle;
    other: LocalKeyHandle;
    nonce?: Uint8Array;
};
export declare type ScanFreeOptions = {
    scanHandle: ScanHandle;
};
export declare type ScanNextOptions = {
    scanHandle: ScanHandle;
};
export declare type ScanStartOptions = {
    storeHandle: StoreHandle;
    category: string;
    profile?: string;
    tagFilter?: Record<string, unknown>;
    offset?: number;
    limit?: number;
};
export declare type SessionCloseOptions = {
    sessionHandle: SessionHandle;
    commit: boolean;
};
export declare type SessionCountOptions = {
    sessionHandle: SessionHandle;
    category: string;
    tagFilter?: Record<string, unknown>;
};
export declare type SessionFetchOptions = {
    sessionHandle: SessionHandle;
    category: string;
    name: string;
    forUpdate: boolean;
};
export declare type SessionFetchAllOptions = {
    sessionHandle: SessionHandle;
    category: string;
    tagFilter?: Record<string, unknown>;
    limit?: number;
    forUpdate: boolean;
};
export declare type SessionFetchAllKeysOptions = {
    sessionHandle: SessionHandle;
    forUpdate: boolean;
    algorithm?: string;
    thumbprint?: string;
    tagFilter?: Record<string, unknown>;
    limit?: number;
};
export declare type SessionFetchKeyOptions = {
    sessionHandle: SessionHandle;
    name: string;
    forUpdate: boolean;
};
export declare type SessionInsertKeyOptions = {
    sessionHandle: SessionHandle;
    localKeyHandle: LocalKeyHandle;
    name: string;
    metadata?: string;
    tags?: Record<string, unknown>;
    expiryMs?: number;
};
export declare type SessionRemoveAllOptions = {
    sessionHandle: SessionHandle;
    category: string;
    tagFilter?: Record<string, unknown>;
};
export declare type SessionRemoveKeyOptions = {
    sessionHandle: SessionHandle;
    name: string;
};
export declare type SessionStartOptions = {
    storeHandle: StoreHandle;
    profile?: string;
    asTransaction: boolean;
};
export declare type SessionUpdateOptions = {
    sessionHandle: SessionHandle;
    operation: number;
    category: string;
    name: string;
    value?: Uint8Array;
    tags?: Record<string, unknown>;
    expiryMs?: number;
};
export declare type SessionUpdateKeyOptions = {
    sessionHandle: SessionHandle;
    name: string;
    metadata?: string;
    tags?: Record<string, unknown>;
    expiryMs?: number;
};
export declare type StoreCloseOptions = {
    storeHandle: StoreHandle;
};
export declare type StoreCreateProfileOptions = {
    storeHandle: StoreHandle;
    profile?: string;
};
export declare type StoreGenerateRawKeyOptions = {
    seed?: Uint8Array;
};
export declare type StoreGetProfileNameOptions = {
    storeHandle: StoreHandle;
};
export declare type StoreOpenOptions = {
    specUri: string;
    keyMethod?: string;
    passKey?: string;
    profile?: string;
};
export declare type StoreProvisionOptions = {
    specUri: string;
    keyMethod?: string;
    passKey?: string;
    profile?: string;
    recreate: boolean;
};
export declare type StoreRekeyOptions = {
    storeHandle: StoreHandle;
    keyMethod?: string;
    passKey: string;
};
export declare type StoreRemoveOptions = {
    specUri: string;
};
export declare type StoreRemoveProfileOptions = {
    storeHandle: StoreHandle;
    profile: string;
};
export declare type MigrateIndySdkOptions = {
    specUri: string;
    walletName: string;
    walletKey: string;
    kdfLevel: string;
};
export declare type AriesAskar = {
    version(): string;
    getCurrentError(): string;
    clearCustomLogger(): void;
    setCustomLogger(options: SetCustomLoggerOptions): void;
    setDefaultLogger(): void;
    setMaxLogLevel(options: SetMaxLogLevelOptions): void;
    entryListCount(options: EntryListCountOptions): number;
    entryListFree(options: EntryListFreeOptions): void;
    entryListGetCategory(options: EntryListGetCategoryOptions): string;
    entryListGetName(options: EntryListGetNameOptions): string;
    entryListGetTags(options: EntryListGetTagsOptions): string | null;
    entryListGetValue(options: EntryListGetValueOptions): Uint8Array;
    keyAeadDecrypt(options: KeyAeadDecryptOptions): Uint8Array;
    keyAeadEncrypt(options: KeyAeadEncryptOptions): EncryptedBuffer;
    keyAeadGetPadding(options: KeyAeadGetPaddingOptions): number;
    keyAeadGetParams(options: KeyAeadGetParamsOptions): AeadParams;
    keyAeadRandomNonce(options: KeyAeadRandomNonceOptions): Uint8Array;
    keyConvert(options: KeyConvertOptions): LocalKeyHandle;
    keyCryptoBox(options: KeyCryptoBoxOptions): Uint8Array;
    keyCryptoBoxOpen(options: KeyCryptoBoxOpenOptions): Uint8Array;
    keyCryptoBoxRandomNonce(): Uint8Array;
    keyCryptoBoxSeal(options: KeyCryptoBoxSealOptions): Uint8Array;
    keyCryptoBoxSealOpen(options: KeyCryptoBoxSealOpenOptions): Uint8Array;
    keyDeriveEcdh1pu(options: KeyDeriveEcdh1puOptions): LocalKeyHandle;
    keyDeriveEcdhEs(options: KeyDeriveEcdhEsOptions): LocalKeyHandle;
    keyEntryListCount(options: KeyEntryListCountOptions): number;
    keyEntryListFree(options: KeyEntryListFreeOptions): void;
    keyEntryListGetAlgorithm(options: KeyEntryListGetAlgorithmOptions): string;
    keyEntryListGetMetadata(options: KeyEntryListGetMetadataOptions): string | null;
    keyEntryListGetName(options: KeyEntryListGetNameOptions): string;
    keyEntryListGetTags(options: KeyEntryListGetTagsOptions): string | null;
    keyEntryListLoadLocal(options: KeyEntryListLoadLocalOptions): LocalKeyHandle;
    keyFree(options: KeyFreeOptions): void;
    keyFromJwk(options: KeyFromJwkOptions): LocalKeyHandle;
    keyFromKeyExchange(options: KeyFromKeyExchangeOptions): LocalKeyHandle;
    keyFromPublicBytes(options: KeyFromPublicBytesOptions): LocalKeyHandle;
    keyFromSecretBytes(options: KeyFromSecretBytesOptions): LocalKeyHandle;
    keyFromSeed(options: KeyFromSeedOptions): LocalKeyHandle;
    keyGenerate(options: KeyGenerateOptions): LocalKeyHandle;
    keyGetAlgorithm(options: KeyGetAlgorithmOptions): string;
    keyGetEphemeral(options: KeyGetEphemeralOptions): number;
    keyGetJwkPublic(options: KeyGetJwkPublicOptions): string;
    keyGetJwkSecret(options: KeyGetJwkSecretOptions): Uint8Array;
    keyGetJwkThumbprint(options: KeyGetJwkThumbprintOptions): string;
    keyGetPublicBytes(options: KeyGetPublicBytesOptions): Uint8Array;
    keyGetSecretBytes(options: KeyGetSecretBytesOptions): Uint8Array;
    keySignMessage(options: KeySignMessageOptions): Uint8Array;
    keyUnwrapKey(options: KeyUnwrapKeyOptions): LocalKeyHandle;
    keyVerifySignature(options: KeyVerifySignatureOptions): boolean;
    keyWrapKey(options: KeyWrapKeyOptions): EncryptedBuffer;
    scanFree(options: ScanFreeOptions): void;
    scanNext(options: ScanNextOptions): Promise<EntryListHandle | null>;
    scanStart(options: ScanStartOptions): Promise<ScanHandle>;
    sessionClose(options: SessionCloseOptions): Promise<void>;
    sessionCount(options: SessionCountOptions): Promise<number>;
    sessionFetch(options: SessionFetchOptions): Promise<EntryListHandle | null>;
    sessionFetchAll(options: SessionFetchAllOptions): Promise<EntryListHandle | null>;
    sessionFetchAllKeys(options: SessionFetchAllKeysOptions): Promise<KeyEntryListHandle | null>;
    sessionFetchKey(options: SessionFetchKeyOptions): Promise<KeyEntryListHandle | null>;
    sessionInsertKey(options: SessionInsertKeyOptions): Promise<void>;
    sessionRemoveAll(options: SessionRemoveAllOptions): Promise<number>;
    sessionRemoveKey(options: SessionRemoveKeyOptions): Promise<void>;
    sessionStart(options: SessionStartOptions): Promise<SessionHandle>;
    sessionUpdate(options: SessionUpdateOptions): Promise<void>;
    sessionUpdateKey(options: SessionUpdateKeyOptions): Promise<void>;
    storeClose(options: StoreCloseOptions): Promise<void>;
    storeCreateProfile(options: StoreCreateProfileOptions): Promise<string>;
    storeGenerateRawKey(options: StoreGenerateRawKeyOptions): string;
    storeGetProfileName(options: StoreGetProfileNameOptions): Promise<string>;
    storeOpen(options: StoreOpenOptions): Promise<StoreHandle>;
    storeProvision(options: StoreProvisionOptions): Promise<StoreHandle>;
    storeRekey(options: StoreRekeyOptions): Promise<void>;
    storeRemove(options: StoreRemoveOptions): Promise<number>;
    storeRemoveProfile(options: StoreRemoveProfileOptions): Promise<number>;
    migrateIndySdk(options: MigrateIndySdkOptions): Promise<void>;
};
